import { BackboneElement, Extension, uri } from 'fhir';
import { ElementBuilder } from './element-builder';
/**
 * Class representing a FHIR Resource builder
 */
export declare class BackboneElementBuilder extends ElementBuilder {
    /**
     * The BackboneElement that is being built
     * @protected
     * @type { BackboneElement }
     * @ignore
     */
    protected element: BackboneElement;
    /**
     * Creates a new FHIR BackboneElementBuilder
     */
    constructor();
    /**
     * Sets a copy of an existing backboneElement for this builder to allow for manipulation
     * If no argument is provided, a new BackboneElement will be generated
     * @param { BackboneElement } backboneElement - the backboneElement to be set
     * @returns { BackboneElementBuilder } The builder
     * @override
     */
    use(backboneElement?: BackboneElement): this;
    /**
     * Returns either the extensions identified by the provided url from the modifierExtension array or the entire modifierExtension array, if no url is provided
     * @param { uri } [url] The url of the extensions to retrieve (if applicable)
     * @returns { Resource | undefined | Resource[] } The extensions if it exists or the modifierExtension-array
     */
    getModifierExtension(url?: uri): Extension[];
    /**
     * Sets the resource's modifierExtension-array to the provided array. If no argument is provided, the field will be removed
     * @param { Extension[] } extensions The array to be set as the resource's modifierExtension array
     * @returns the Builder
     */
    setModifierExtension(extension?: Extension[]): this;
    /**
     * Adds the extension provided as an argument to the resource's modifierExtension array
     * @param extension The resource to be added to the modifierExtension array
     * @returns the Builder
     */
    addModifierExtension(extension: Extension): this;
    /**
     * Make a new object that implements a FHIR BackboneElement
     * @returns { BackboneElement } An object that implements FHIR BackboneElement
     * @override
     */
    protected make(): BackboneElement;
    /**
     * Builds and returns the backboneElement
     * @returns { BackboneElement } The backboneElement
     * @override
     */
    build(): BackboneElement;
}
