import { Coding, code } from 'fhir';
import { ElementBuilder } from './element-builder';
/** A class representing a FHIR CodingBuilder */
export declare class CodingBuilder extends ElementBuilder {
    /**
     * The Coding being built
     * @private
     * @type { Coding }
     * @ignore
     */
    protected element: Coding;
    /**
     * Creates a new CodingBuilder
     */
    constructor();
    /**
     * Sets a copy of an existing coding for this builder to allow for manipulation,
     * If no argument is provided, a new Coding will be generated
     * @param { Coding } coding - the coding to be set
     * @returns { CodingBuilder } The builder
     * @override
     */
    use(coding?: Coding): this;
    /**
     * Returns the system-field of the Coding
     * @returns { string } The system-field
     */
    getSystem(): string | undefined;
    /**
     * Sets the system-field of the Coding
     * If no argument is provided, the field will be removed
     * @param { string } system - The value to be set in the system-field
     * @returns { CodingBuilder } - This CodingBuilder
     */
    setSystem(system?: string): this;
    /**
     * Returns the version-field of the Coding
     * @returns { string } The version-field
     */
    getVersion(): string | undefined;
    /**
     * Sets the version-field of the Coding
     * If no argument is provided, the field will be removed
     * @param { string } version - The value to be set in the version-field
     * @returns { CodingBuilder } - This CodingBuilder
     */
    setVersion(version?: string): this;
    /**
     * Returns the code-field of the Coding
     * @returns { code } The code-field
     */
    getCode(): code | undefined;
    /**
     * Sets the code-field of the Coding
     * If no argument is provided, the field will be removed
     * @param { code } code - The value to be set in the code-field
     * @returns { CodingBuilder } - This CodingBuilder
     */
    setCode(code?: code): this;
    /**
     * Returns the display-field of the Coding
     * @returns { string } The display-field
     */
    getDisplay(): string | undefined;
    /**
     * Sets the display-field of the Coding
     * If no argument is provided, the field will be removed
     * @param { string } display - The value to be set in the display-field
     * @returns { CodingBuilder } - This CodingBuilder
     */
    setDisplay(display?: string): this;
    /**
     * Returns the userSelected-field of the Coding
     * @returns { boolean } The userSelected-field
     */
    getUserSelected(): boolean | undefined;
    /**
     * Sets the userSelected-field of the Coding
     * If no argument is provided, the field will be removed
     * @param { boolean } userSelected - The value to be set in the userSelected-field
     * @returns { CodingBuilder } - This CodingBuilder
     */
    setUserSelected(userSelected?: boolean): this;
    /**
     * Creates a new Coding
     * @returns { Coding } The coding
     * @override
     */
    protected make(): Coding;
    /**
     * Builds and returns the Coding
     * @returns { Coding } - the Coding
     * @override
     */
    build(): Coding;
}
