import { Extension, uri, Reference, base64Binary, canonical, code, date, dateTime, decimal, id, instant, integer, markdown, oid, positiveInt, time, unsignedInt, url, uuid, Address, Age, Annotation, Attachment, CodeableConcept, Coding, ContactPoint, Count, Distance, Duration, HumanName, Identifier, Money, Period, Quantity, Ratio, SampledData, Signature, Timing, Meta, Range } from 'fhir';
import { ElementBuilder } from './element-builder';
/** Class representing a FHIR  */
export declare class ExtensionBuilder extends ElementBuilder {
    /**
     * The Extension that is being built
     * @protected
     * @type { Extension }
     * @ignore
     */
    protected element: Extension;
    /**
     * Create a new FHIR ExtensionBuilder
     */
    constructor();
    /**
     * Sets a copy of an already existing extension as the element to build
     * If no argument is provided, a new Extension will be generated
     * @returns { ExtensionBuilder } The builder
     * @override
     */
    use(extension?: Extension): this;
    /**
     * Returns the url-field of the CarePlanActivity if it is set
     * @returns { Extension } The url-field
     */
    getUrl(): uri | undefined;
    /**
     * Sets the url-field of the CarePlanActivity with the provided uri
     * If no argument is provided, the field will be removed
     * @returns { CarePlanActivityBuilder } The builder
     */
    setUrl(url?: uri): this;
    /**
     * Returns the valueBase64Binary-field of the Extension
     * @returns The valueBase64Binary-field
     */
    getValueBase64Binary(): base64Binary | undefined;
    /**
     * Sets the valueBase64Binary-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { base64Binary } valueBase64Binary - The value to be set in the valueBase64Binary-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueBase64Binary(valueBase64Binary?: base64Binary): this;
    /**
     * Returns the valueBoolean-field of the Extension
     * @returns The valueBoolean-field
     */
    getValueBoolean(): boolean | undefined;
    /**
     * Sets the valueBoolean-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { boolean } valueBoolean - The value to be set in the valueBoolean-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueBoolean(valueBoolean?: boolean): this;
    /**
     * Returns the valueCanonical-field of the Extension
     * @returns The valueCanonical-field
     */
    getValueCanonical(): canonical | undefined;
    /**
     * Sets the valueCanonical-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { canonical } valueCanonical - The value to be set in the valueCanonical-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueCanonical(valueCanonical?: canonical): this;
    /**
     * Returns the valueCode-field of the Extension
     * @returns The valueCode-field
     */
    getValueCode(): code | undefined;
    /**
     * Sets the valueCode-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { code } valueCode - The value to be set in the valueCode-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueCode(valueCode?: code): this;
    /**
     * Returns the valueDate-field of the Extension
     * @returns The valueDate-field
     */
    getValueDate(): date | undefined;
    /**
     * Sets the valueDate-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { date } valueDate - The value to be set in the valueDate-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueDate(valueDate?: date): this;
    /**
     * Returns the valueDateTime-field of the Extension
     * @returns The valueDateTime-field
     */
    getValueDateTime(): dateTime | undefined;
    /**
     * Sets the valueDateTime-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { dateTime } valueDateTime - The value to be set in the valueDateTime-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueDateTime(valueDateTime?: dateTime): this;
    /**
     * Returns the valueDecimal-field of the Extension
     * @returns The valueDecimal-field
     */
    getValueDecimal(): decimal | undefined;
    /**
     * Sets the valueDecimal-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { decimal } valueDecimal - The value to be set in the valueDecimal-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueDecimal(valueDecimal?: decimal): this;
    /**
     * Returns the valueId-field of the Extension
     * @returns The valueId-field
     */
    getValueId(): id | undefined;
    /**
     * Sets the valueId-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { id } valueId - The value to be set in the valueId-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueId(valueId?: id): this;
    /**
     * Returns the valueInstant-field of the Extension
     * @returns The valueInstant-field
     */
    getValueInstant(): instant | undefined;
    /**
     * Sets the valueInstant-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { instant } valueInstant - The value to be set in the valueInstant-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueInstant(valueInstant?: instant): this;
    /**
     * Returns the valueInteger-field of the Extension
     * @returns The valueInteger-field
     */
    getValueInteger(): integer | undefined;
    /**
     * Sets the valueInteger-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { integer } valueInteger - The value to be set in the valueInteger-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueInteger(valueInteger?: integer): this;
    /**
     * Returns the valueMarkdown-field of the Extension
     * @returns The valueMarkdown-field
     */
    getValueMarkdown(): markdown | undefined;
    /**
     * Sets the valueMarkdown-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { markdown } valueMarkdown - The value to be set in the valueMarkdown-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueMarkdown(valueMarkdown?: markdown): this;
    /**
     * Returns the valueOid-field of the Extension
     * @returns The valueOid-field
     */
    getValueOid(): oid | undefined;
    /**
     * Sets the valueOid-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { oid } valueOid - The value to be set in the valueOid-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueOid(valueOid?: oid): this;
    /**
     * Returns the valuePositiveInt-field of the Extension
     * @returns The valuePositiveInt-field
     */
    getValuePositiveInt(): positiveInt | undefined;
    /**
     * Sets the valuePositiveInt-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { positiveInt } valuePositiveInt - The value to be set in the valuePositiveInt-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValuePositiveInt(valuePositiveInt?: positiveInt): this;
    /**
     * Returns the valueString-field of the Extension
     * @returns The valueString-field
     */
    getValueString(): string | undefined;
    /**
     * Sets the valueString-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { string } valueString - The value to be set in the valueString-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueString(valueString?: string): this;
    /**
     * Returns the valueTime-field of the Extension
     * @returns The valueTime-field
     */
    getValueTime(): time | undefined;
    /**
     * Sets the valueTime-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { time } valueTime - The value to be set in the valueTime-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueTime(valueTime?: time): this;
    /**
     * Returns the valueUnsignedInt-field of the Extension
     * @returns The valueUnsignedInt-field
     */
    getValueUnsignedInt(): unsignedInt | undefined;
    /**
     * Sets the valueUnsignedInt-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { unsignedInt } valueUnsignedInt - The value to be set in the valueUnsignedInt-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueUnsignedInt(valueUnsignedInt?: unsignedInt): this;
    /**
     * Returns the valueUri-field of the Extension
     * @returns The valueUri-field
     */
    getValueUri(): uri | undefined;
    /**
     * Sets the valueUri-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { uri } valueUri - The value to be set in the valueUri-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueUri(valueUri?: uri): this;
    /**
     * Returns the valueUrl-field of the Extension
     * @returns The valueUrl-field
     */
    getValueUrl(): url | undefined;
    /**
     * Sets the valueUrl-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { url } valueUrl - The value to be set in the valueUrl-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueUrl(valueUrl?: url): this;
    /**
     * Returns the valueUuid-field of the Extension
     * @returns The valueUuid-field
     */
    getValueUuid(): uuid | undefined;
    /**
     * Sets the valueUuid-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { uuid } valueUuid - The value to be set in the valueUuid-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueUuid(valueUuid?: uuid): this;
    /**
     * Returns the valueAddress-field of the Extension
     * @returns The valueAddress-field
     */
    getValueAddress(): Address | undefined;
    /**
     * Sets the valueAddress-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { Address } valueAddress - The value to be set in the valueAddress-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueAddress(valueAddress?: Address): this;
    /**
     * Returns the valueAge-field of the Extension
     * @returns The valueAge-field
     */
    getValueAge(): Age | undefined;
    /**
     * Sets the valueAge-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { Age } valueAge - The value to be set in the valueAge-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueAge(valueAge?: Age): this;
    /**
     * Returns the valueAnnotation-field of the Extension
     * @returns The valueAnnotation-field
     */
    getValueAnnotation(): Annotation | undefined;
    /**
     * Sets the valueAnnotation-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { Annotation } valueAnnotation - The value to be set in the valueAnnotation-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueAnnotation(valueAnnotation?: Annotation): this;
    /**
     * Returns the valueAttachment-field of the Extension
     * @returns The valueAttachment-field
     */
    getValueAttachment(): Attachment | undefined;
    /**
     * Sets the valueAttachment-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { Attachment } valueAttachment - The value to be set in the valueAttachment-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueAttachment(valueAttachment?: Attachment): this;
    /**
     * Returns the valueCodeableConcept-field of the Extension
     * @returns The valueCodeableConcept-field
     */
    getValueCodeableConcept(): CodeableConcept | undefined;
    /**
     * Sets the valueCodeableConcept-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { CodeableConcept } valueCodeableConcept - The value to be set in the valueCodeableConcept-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueCodeableConcept(valueCodeableConcept?: CodeableConcept): this;
    /**
     * Returns the valueCoding-field of the Extension
     * @returns The valueCoding-field
     */
    getValueCoding(): Coding | undefined;
    /**
     * Sets the valueCoding-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { Coding } valueCoding - The value to be set in the valueCoding-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueCoding(valueCoding?: Coding): this;
    /**
     * Returns the valueContactPoint-field of the Extension
     * @returns The valueContactPoint-field
     */
    getValueContactPoint(): ContactPoint | undefined;
    /**
     * Sets the valueContactPoint-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { ContactPoint } valueContactPoint - The value to be set in the valueContactPoint-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueContactPoint(valueContactPoint?: ContactPoint): this;
    /**
     * Returns the valueCount-field of the Extension
     * @returns The valueCount-field
     */
    getValueCount(): Count | undefined;
    /**
     * Sets the valueCount-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { Count } valueCount - The value to be set in the valueCount-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueCount(valueCount?: Count): this;
    /**
     * Returns the valueDistance-field of the Extension
     * @returns The valueDistance-field
     */
    getValueDistance(): Distance | undefined;
    /**
     * Sets the valueDistance-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { Distance } valueDistance - The value to be set in the valueDistance-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueDistance(valueDistance?: Distance): this;
    /**
     * Returns the valueDuration-field of the Extension
     * @returns The valueDuration-field
     */
    getValueDuration(): Duration | undefined;
    /**
     * Sets the valueDuration-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { Duration } valueDuration - The value to be set in the valueDuration-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueDuration(valueDuration?: Duration): this;
    /**
     * Returns the valueHumanName-field of the Extension
     * @returns The valueHumanName-field
     */
    getValueHumanName(): HumanName | undefined;
    /**
     * Sets the valueHumanName-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { HumanName } valueHumanName - The value to be set in the valueHumanName-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueHumanName(valueHumanName?: HumanName): this;
    /**
     * Returns the valueIdentifier-field of the Extension
     * @returns The valueIdentifier-field
     */
    getValueIdentifier(): Identifier | undefined;
    /**
     * Sets the valueIdentifier-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { Identifier } valueIdentifier - The value to be set in the valueIdentifier-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueIdentifier(valueIdentifier?: Identifier): this;
    /**
     * Returns the valueMoney-field of the Extension
     * @returns The valueMoney-field
     */
    getValueMoney(): Money | undefined;
    /**
     * Sets the valueMoney-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { Money } valueMoney - The value to be set in the valueMoney-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueMoney(valueMoney?: Money): this;
    /**
     * Returns the valuePeriod-field of the Extension
     * @returns The valuePeriod-field
     */
    getValuePeriod(): Period | undefined;
    /**
     * Sets the valuePeriod-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { Period } valuePeriod - The value to be set in the valuePeriod-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValuePeriod(valuePeriod?: Period): this;
    /**
     * Returns the valueQuantity-field of the Extension
     * @returns The valueQuantity-field
     */
    getValueQuantity(): Quantity | undefined;
    /**
     * Sets the valueQuantity-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { Quantity } valueQuantity - The value to be set in the valueQuantity-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueQuantity(valueQuantity?: Quantity): this;
    /**
     * Returns the valueRange-field of the Extension
     * @returns The valueRange-field
     */
    getValueRange(): Range | undefined;
    /**
     * Sets the valueRange-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { Range } valueRange - The value to be set in the valueRange-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueRange(valueRange?: Range): this;
    /**
     * Returns the valueRatio-field of the Extension
     * @returns The valueRatio-field
     */
    getValueRatio(): Ratio | undefined;
    /**
     * Sets the valueRatio-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { Ratio } valueRatio - The value to be set in the valueRatio-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueRatio(valueRatio?: Ratio): this;
    /**
     * Returns the valueReference-field of the CarePlanActivity if it is set
     * @returns { Reference } The valueReference-field
     */
    getValueReference(): Reference | undefined;
    /**
     * Sets the valueReference-field of the CarePlanActivity with the provided reference
     * If no argument is provided, the field will be removed
     * @returns { CarePlanActivityBuilder } The builder
     */
    setValueReference(valueReference?: Reference): this;
    /**
     * Returns the valueSampledData-field of the Extension
     * @returns The valueSampledData-field
     */
    getValueSampledData(): SampledData | undefined;
    /**
     * Sets the valueSampledData-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { SampledData } valueSampledData - The value to be set in the valueSampledData-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueSampledData(valueSampledData?: SampledData): this;
    /**
     * Returns the valueSignature-field of the Extension
     * @returns The valueSignature-field
     */
    getValueSignature(): Signature | undefined;
    /**
     * Sets the valueSignature-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { Signature } valueSignature - The value to be set in the valueSignature-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueSignature(valueSignature?: Signature): this;
    /**
     * Returns the valueTiming-field of the Extension
     * @returns The valueTiming-field
     */
    getValueTiming(): Timing | undefined;
    /**
     * Sets the valueTiming-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { Timing } valueTiming - The value to be set in the valueTiming-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueTiming(valueTiming?: Timing): this;
    /**
     * Returns the valueMeta-field of the Extension
     * @returns The valueMeta-field
     */
    getValueMeta(): Meta | undefined;
    /**
     * Sets the valueMeta-field of the Extension
     * If no argument is provided, the field will be removed
     * @param { Meta } valueMeta - The value to be set in the valueMeta-field
     * @returns { ExtensionBuilder } - The builder
     */
    setValueMeta(valueMeta?: Meta): this;
    /**
     * Make a new object that implements a FHIR Extension
     * @returns { Extension } - an object that implements FHIR Extension
     * @override
     */
    protected make(): Extension;
    /**
     * Returns the extension
     * @returns { Extension } The extension
     * @override
     */
    build(): Extension;
}
