import { Identifier, Reference } from 'fhir';
import { ElementBuilder } from './element-builder';
/** Class representing a FHIR  */
export declare class ReferenceBuilder extends ElementBuilder {
    /**
     * The Reference that is being built
     * @protected
     * @type { Reference }
     * @ignore
     */
    protected element: Reference;
    /**
     * Create a new FHIR ReferenceBuilder
     */
    constructor();
    /**
     * Sets a copy of an existing reference for this builder to allow for manipulation
     * If no argument is provided, a new Reference will be generated
     * @param { Reference } coding - the reference to be set
     * @returns { ReferenceBuilder } The builder
     * @override
     */
    use(reference?: Reference): this;
    /**
     * Returns the reference-field of the Reference
     * @returns { string } The reference-field
     */
    getReference(): string | undefined;
    /**
     * Sets the reference-field of the Reference
     * If no argument is provided, the field will be removed
     * @param { string } reference - The value to be set in the reference-field
     * @returns { ReferenceBuilder } - This ReferenceBuilder
     */
    setReference(reference?: string): this;
    /**
     * Returns the type-field of the Reference
     * @returns { string } The type-field
     */
    getType(): string | undefined;
    /**
     * Sets the type-field of the Reference
     * If no argument is provided, the field will be removed
     * @param { string } type - The value to be set in the type-field
     * @returns { ReferenceBuilder } - This ReferenceBuilder
     */
    setType(type?: string): this;
    /**
     * Returns the identifier-field of the Reference
     * @returns { Identifier } The identifier-field
     */
    getIdentifier(): Identifier | undefined;
    /**
     * Sets the identifier-field of the Reference
     * If no argument is provided, the field will be removed
     * @param { Identifier } identifier - The value to be set in the identifier-field
     * @returns { ReferenceBuilder } - This ReferenceBuilder
     */
    setIdentifier(identifier?: Identifier): this;
    /**
     * Returns the display-field of the Reference
     * @returns { string } The display-field
     */
    getDisplay(): string | undefined;
    /**
     * Sets the display-field of the Reference
     * If no argument is provided, the field will be removed
     * @param { string } display - The value to be set in the display-field
     * @returns { ReferenceBuilder } - This ReferenceBuilder
     */
    setDisplay(display?: string): this;
    /**
     * Returns whether or not the reference provided as an argument is in conflict with the reference used in the builder
     * @param { Reference } reference The reference to test for conflict
     * @returns { boolean } Whether it is in conflict
     * @override
     */
    conflictsWith(reference: Reference): boolean;
    /**
     * Make a new object that implements a FHIR Reference
     * @returns { Reference } - an object that implements FHIR Reference
     * @override
     */
    protected make(): Reference;
    /**
     * Returns the reference
     * @returns { Reference } The reference
     * @override
     */
    build(): Reference;
}
