import { TaskInput, CodeableConcept, canonical, Reference } from 'fhir';
import { BackboneElementBuilder } from './backbone-element-builder';
/** A class representing a FHIR TaskInputBuilder */
export declare class TaskInputBuilder extends BackboneElementBuilder {
    /**
     * The TaskInput being built
     * @private
     * @type { TaskInput }
     * @ignore
     */
    protected element: TaskInput;
    /**
     * Creates a new TaskInputBuilder
     */
    constructor();
    /**
     * Sets a copy of an existing taskInput for this builder to allow for manipulation
     * If no argument is provided, a new TaskInput will be generated
     * @param { TaskInput } taskInput - the taskInput to be set
     * @returns { TaskInputBuilder } The builder
     * @override
     */
    use(taskInput?: TaskInput): this;
    /**
     * Returns the type-field of the TaskInput
     * @returns { CodeableConcept } The type-field
     */
    getType(): CodeableConcept | undefined;
    /**
     * Sets the type-field of the TaskInput
     * If no argument is provided, the field will be removed
     * @param { CodeableConcept } type - The value to be set in the type-field
     * @returns { TaskInputBuilder } - This TaskInputBuilder
     */
    setType(type?: CodeableConcept): this;
    /**
     * Returns the valueCanonical-field of the TaskInput
     * @returns { canonical } The valueCanonical-field
     */
    getValueCanonical(): canonical | undefined;
    /**
     * Sets the valueCanonical-field of the TaskInput
     * If no argument is provided, the field will be removed
     * @param { canonical } valueCanonical - The value to be set in the valueCanonical-field
     * @returns { TaskInputBuilder } - This TaskInputBuilder
     */
    setValueCanonical(valueCanonical?: canonical): this;
    /**
     * Returns the valueReference-field of the TaskInput
     * @returns { Reference } The valueReference-field
     */
    getValueReference(): Reference | undefined;
    /**
     * Sets the valueReference-field of the TaskInput
     * If no argument is provided, the field will be removed
     * @param { Reference } valueReference - The value to be set in the valueReference-field
     * @returns { TaskInputBuilder } - This TaskInputBuilder
     */
    setValueReference(valueReference?: Reference): this;
    /**
     * Returns whether or not the taskInput provided as an argument is in conflict with the taskInput used in the builder
     * @param { TaskInput } taskInput The taskInput to test for conflict
     * @returns { boolean } Whether it is in conflict
     * @override
     */
    conflictsWith(taskInput: TaskInput): boolean;
    /**
     * Creates a new TaskInput
     * @returns { TaskInput } The taskInput
     * @override
     */
    protected make(): TaskInput;
    /**
     * Builds and returns the TaskInput
     * @returns { TaskInput } - the TaskInput
     * @override
     */
    build(): TaskInput;
}
