import { Extension, Coding, decimal, integer, date, dateTime, uri, Attachment, CodeableConcept, Quantity, Reference } from 'fhir';
import { ElementBuilder } from './element-builder';
/**
 * Class representing an EffectiveWhen builder for ThresholdSet Thresholds
 */
export declare class ThresholdEffectiveWhenBuilder extends ElementBuilder {
    /**
     * The effectiveWhen that is being built
     * @protected
     * @type { Extension }
     * @ignore
     */
    protected element: Extension;
    /**
     * Creates a new EffectiveWhen for FHIR ThresholdSet Threholds
     */
    constructor();
    /**
     * Sets a copy of an existing effectiveWhen for this builder to allow for manipulating, or interacting with, the
     * effectiveWhen through this builder
     * If no argument is provided, a new ThresholdEffectiveWhen will be generated
     * @param { Extension } threshold - The effectiveWhen to set
     * @returns { ThresholdEffectiveWhenBuilder } The builder
     * @override
     */
    use(effectiveWhen?: Extension): this;
    /**
     * Returns the component on which this effectiveWhen is acting
     * @returns { Coding } The component
     */
    getComponent(): Coding | undefined;
    /**
     * Sets the component on which this effectiveWhen is acting
     * If no argument is provided, the field will be removed
     * @param { Coding } component - The component
     * @returns { ThresholdEffectiveWhenBuilder } - The builder
     */
    setComponent(component?: Coding): this;
    /**
     * Returns the valueBoolean of the effectiveWhen
     * @returns { boolean } The valueBoolean
     */
    getValueBoolean(): boolean | undefined;
    /**
     * Sets the valueBoolean of the effectiveWhen
     * If no argument is provided, the field will be removed
     * @param { boolean } valueBoolean - The valueBoolean
     * @returns { ThresholdEffectiveWhenBuilder } - The builder
     */
    setValueBoolean(bool?: boolean): this;
    /**
     * Returns the valueDecimal of the effectiveWhen
     * @returns { decimal } The valueDecimal
     */
    getValueDecimal(): decimal | undefined;
    /**
     * Sets the valueDecimal of the effectiveWhen
     * If no argument is provided, the field will be removed
     * @param { decimal } valueDecimal - The valueDecimal
     * @returns { ThresholdEffectiveWhenBuilder } - The builder
     */
    setValueDecimal(decimal?: decimal): this;
    /**
     * Returns the valueInteger of the effectiveWhen
     * @returns { integer } The valueInteger
     */
    getValueInteger(): integer | undefined;
    /**
     * Sets the valueInteger of the effectiveWhen
     * If no argument is provided, the field will be removed
     * @param { integer } valueInteger - The valueInteger
     * @returns { ThresholdEffectiveWhenBuilder } - The builder
     */
    setValueInteger(integer?: integer): this;
    /**
     * Returns the valueString of the effectiveWhen
     * @returns { string } The valueString
     */
    getValueString(): string | undefined;
    /**
     * Sets the valueString of the effectiveWhen
     * If no argument is provided, the field will be removed
     * @param { string } valueString - The valueString
     * @returns { ThresholdEffectiveWhenBuilder } - The builder
     */
    setValueString(str?: string): this;
    /**
     * Returns the valueDate of the effectiveWhen
     * @returns { date } The valueDate
     */
    getValueDate(): date | undefined;
    /**
     * Sets the valueDate of the effectiveWhen
     * If no argument is provided, the field will be removed
     * @param { date } valueDate - The valueDate
     * @returns { ThresholdEffectiveWhenBuilder } - The builder
     */
    setValueDate(date?: date): this;
    /**
     * Returns the valueDateTime of the effectiveWhen
     * @returns { dateTime } The valueDateTime
     */
    getValueDateTime(): dateTime | undefined;
    /**
     * Sets the valueDateTime of the effectiveWhen
     * If no argument is provided, the field will be removed
     * @param { dateTime } valueDateTime - The valueDateTime
     * @returns { ThresholdEffectiveWhenBuilder } - The builder
     */
    setValueDateTime(dateTime?: dateTime): this;
    /**
     * Returns the valueUri of the effectiveWhen
     * @returns { uri } The valueUri
     */
    getValueUri(): uri | undefined;
    /**
     * Sets the valueUri of the effectiveWhen
     * If no argument is provided, the field will be removed
     * @param { uri } valueUri - The valueUri
     * @returns { ThresholdEffectiveWhenBuilder } - The builder
     */
    setValueUri(uri?: uri): this;
    /**
     * Returns the valueAttachment of the effectiveWhen
     * @returns { Attachment } The valueAttachment
     */
    getValueAttachment(): Attachment | undefined;
    /**
     * Sets the valueAttachment of the effectiveWhen
     * If no argument is provided, the field will be removed
     * @param { Attachment } valueAttachment - The valueAttachment
     * @returns { ThresholdEffectiveWhenBuilder } - The builder
     */
    setValueAttachment(attachment?: Attachment): this;
    /**
     * Returns the valueCodeableConcept of the effectiveWhen
     * @returns { CodeableConcept } The valueCodeableConcept
     */
    getValueCodeableConcept(): CodeableConcept | undefined;
    /**
     * Sets the valueCodeableConcept of the effectiveWhen
     * If no argument is provided, the field will be removed
     * @param { CodeableConcept } valueCodeableConcept - The valueCodeableConcept
     * @returns { ThresholdEffectiveWhenBuilder } - The builder
     */
    setValueCodeableConcept(codeableConcept?: CodeableConcept): this;
    /**
     * Returns the valueQuantity of the effectiveWhen
     * @returns { Quantity } The valueQuantity
     */
    getValueQuantity(): Quantity | undefined;
    /**
     * Sets the valueQuantity of the effectiveWhen
     * If no argument is provided, the field will be removed
     * @param { Quantity } valueQuantity - The valueQuantity
     * @returns { ThresholdEffectiveWhenBuilder } - The builder
     */
    setValueQuantity(quantity?: Quantity): this;
    /**
     * Returns the valueReference of the effectiveWhen
     * @returns { Reference } The valueReference
     */
    getValueReference(): Reference | undefined;
    /**
     * Sets the valueReference of the effectiveWhen
     * If no argument is provided, the field will be removed
     * @param { Reference } valueReference - The valueReference
     * @returns { ThresholdEffectiveWhenBuilder } - The builder
     */
    setValueReference(reference?: Reference): this;
    /**
     * Returns the operator of the effectiveWhen
     * @returns { EffectiveWhenOperator } The operator
     */
    getOperator(): EffectiveWhenOperator | undefined;
    /**
     * Sets the operator of the effectiveWhen
     * If no argument is provided, the field will be removed
     * @param { EffectiveWhenOperator } operator - The operator
     * @returns { ThresholdEffectiveWhenBuilder } - The builder
     */
    setOperator(operator?: EffectiveWhenOperator): this;
    /**
     * Make a new object that implements a FHIR ThresholdSet
     * @returns { ThresholdSet } - an object that implements FHIR ThresholdSet
     * @override
     */
    protected make(): Extension;
    /**
     * Builds and returns the plandefinition
     * @returns { Extension } - the plandefinition
     * @override
     */
    build(): Extension;
}
/**
 * All possible values of effectiveWhen.operator
 */
declare type EffectiveWhenOperator = 'exists' | '=' | '!=' | '>' | '<' | '>=' | '<=';
export {};
