import { Extension, CodeableConcept } from 'fhir';
import { ElementBuilder } from './element-builder';
/**
 * Class representing a Threshold builder for Fhir ThresholdSets
 */
export declare class ThresholdSetThresholdBuilder extends ElementBuilder {
    /**
     * The threshold that is being built
     * @protected
     * @type { Extension }
     * @ignore
     */
    protected element: Extension;
    /**
     * Creates a new Threshold for FHIR ThresholdSets
     */
    constructor();
    /**
     * Sets a copy of an existing threshold for this builder to allow for manipulating, or interacting with, the
     * threshold through this builder
     * If no argument is provided, a new ThresholdSetThreshold will be generated
     * @param { Extension } threshold - The threshold to set
     * @returns { ThresholdSetBuilder } The builder
     * @override
     */
    use(threshold?: Extension): this;
    /**
     * Returns the type of the threshold
     * @returns { CodeableConcept } The version
     */
    getType(): CodeableConcept | undefined;
    /**
     * Sets the type of the threshold
     * If no argument is provided, the field will be removed
     * @param { CodeableConcept } type - The type
     * @returns { ThresholdSetBuilder } - The builder
     */
    setType(type?: CodeableConcept): this;
    /**
     * Returns an array of effectiveWhens in the form of extensions
     * @returns { Extension[] } The array of effectiveWhens as extensions
     */
    getEffectiveWhen(): Extension[];
    /**
     * Sets the effectiveWhen array of the thresholdSet
     * If no argument is provided, the field will be removed
     * @param { Extension[] } threshold - The effectiveWhen array
     * @returns { ThresholdSetThresholdBuilder } - The builder
     */
    setEffectiveWhen(effectiveWhen?: Extension[]): this;
    /**
     * Adds an effectiveWhen to the effectiveWhen array of the threshold
     * @param { Extension } effectiveWhen - The effectiveWhen to add to the effectiveWhen-array
     * @returns { ThresholdSetThresholdBuilder } - The builder
     */
    addEffectiveWhen(effectiveWhen: Extension): this;
    /**
     * Returns whether the threshold is in effect if all or any of the effectiveWhens are in effect
     * @returns { ThresholdEffectiveBehavior } The effectiveBehavior
     */
    getEffectiveBehavior(): ThresholdEffectiveBehavior | undefined;
    /**
     * Sets whether the threshold is in effect if all or any of the effectiveWhens are in effect
     * If no argument is provided, the field will be removed
     * @param { ThresholdEffectiveBehavior } effectiveBehavior - The effectiveBehavior
     * @returns { ThresholdSetThresholdBuilder } - The builder
     */
    setEffectiveBehavior(effectiveBehavior?: ThresholdEffectiveBehavior): this;
    /**
     * Make a new object that implements a FHIR ThresholdSet
     * @returns { ThresholdSet } - an object that implements FHIR ThresholdSet
     * @override
     */
    protected make(): Extension;
    /**
     * Builds and returns the plandefinition
     * @returns { Extension } - the plandefinition
     * @override
     */
    build(): Extension;
}
/**
 * All possible values of Threshold.effectiveBehavior
 */
declare type ThresholdEffectiveBehavior = 'all' | 'any';
export {};
