import { CarePlan, PlanDefinition, canonical, Task, Basic, Resource, CarePlanActivity, PlanDefinitionAction } from 'fhir';
import { PlanDefinitionActionBuilder } from '..';
/**
 * Adds all content from the PlanDefinition to the CarePlan
 * @param { PlanDefinition } planDefinition The PlanDefinition to copy content from
 * @param { CarePlan } carePlan The CarePlan to copy content to
 * @return { CarePlan } A new CarePlan containing the content the provided CarePlan contained,
 * along with the newly copied content
 * @throws { MissingPropertyError } When PlanDefinition or CarePLan is missing necessary properties
 * @throws { Error } References malformed
 */
declare const planDefinitionToCarePlan: (pd: PlanDefinition, cp: CarePlan) => CarePlan;
/**
 * Creates an Activity from a PlanDefinitionAction and a ThresholdSet and adds it to the CarePlan
 * @param { PlanDefinitionAction }planDefinitionAction The Action from which to create the Activity
 * @param { Basic } thresholdSet The ThresholdSet for the resource
 * @param { CarePlan } carePlan The CarePlan to which the activity should be added
 * @returns { CarePlan } A new CarePlan containing the newly added activity
 * @throws { MissingPropertyError } if PlanDefinitionAction contains no definitionCanonical
 * @throws { AlreadyExistsError } if the action or thresholdSet is in conflict with the existing resources on the CarePlan
 */
declare const actionToActivity: (action: PlanDefinitionAction, thresholdSet: Basic, carePlan: CarePlan) => CarePlan;
/**
 * Creates a task with the canonical reference provided
 * @returns { Task } The created task
 */
declare const _createTask: (reference: canonical) => Task;
/**
 * Handles potential conflicts that could arise when adding a resource to a CarePlan's contained-array
 * @param { Resource } resource The resource that is to be added to the CarePlan's contained-array
 * @param { CarePlan } carePlan The CarePlan
 * @returns The resource in a form where it can be added to the CarePlan's contained-array
 * @throws { AlreadyExistsError } If the CarePlan's contained-array already contains a resource that
 * references the same resource that the provided resource does
 */
declare const _handleIdConflicts: (resource: Resource, carePlan: CarePlan) => Resource;
/**
 * Retrieves reference to thresholdSet from PlanDefinitionAction
 * @param { PlanDefinitionActionBuilder } planDefinitionActionBuilder The planDefinitionActionBuilder
 * @returns { string } The reference
 */
declare const _getThresholdSetReference: (planDefinitionActionBuilder: PlanDefinitionActionBuilder) => string | undefined;
/**
 * Creates a CarePlanActivity from provided taskId and thresholdSetId
 * @param { string } taskId The id for the task
 * @param { string } thresholdSetId The id for the thresholdSet
 * @returns { CarePlanActivity } The CarePlanActivity
 */
declare const _createActivity: (taskId: string | undefined, thresholdSetId: string | undefined) => CarePlanActivity;
/**
 * Generates a random four character string
 * @returns { string } A random four character string
 */
declare const _generateRandomFourCharString: () => string;
export { planDefinitionToCarePlan, actionToActivity, _createTask, _handleIdConflicts, _getThresholdSetReference, _createActivity, _generateRandomFourCharString, };
