/**
 * A class containing all constants
 */
export class Constants {
  /**
   * A map of the extensions that different extension-url's that exist for CarePlan
   */
  public static readonly carePlan: {
    /**
     * The url for the activity.thresholdSet extension
     */
    thresholdSet: string
  } = {
    thresholdSet:
      'https://issuetracker4s.atlassian.net/wiki/spaces/FHIRReg/pages/100728833/CarePlan+thresholdset+extension',
  }

  /**
   * A map of the extensions that different extension-url's that exist for PlanDefinition
   */
  public static readonly planDefinition: {
    /**
     * The url for the action.thresholdSet extension
     */
    thresholdSet: string
  } = {
    thresholdSet:
      'https://issuetracker4s.atlassian.net/wiki/spaces/FHIRReg/pages/100466689/PlanDefinition+threshold+extension',
  }

  /**
   * A map of the extensions that different extension-url's that exist for ThresholdSet
   */
  public static readonly thresholdSet: {
    /**
     * The url for the version extension
     */
    version: string
    /**
     * The url for the status extension
     */
    status: string
    /**
     * The url for the approvalDate extension
     */
    approvalDate: string
    /**
     * The url for the approvingPractitioner extension
     */
    approvingPractitioner: string
    /**
     * The url for the appliesTo extension
     */
    appliesTo: string
    /**
     * The url for the threshold extension
     */
    threshold: string
    /**
     * The url for the threshold.type extension
     */
    type: string
    /**
     * The url for the threshold.effectiveWhen extension
     */
    effectiveWhen: string
    /**
     * The url for the threshold.effectiveBehavior extension
     */
    effectiveBehavior: string
    /**
     * The url for the threshold.effectiveWhen.component extension
     */
    component: string
    /**
     * The url for the threshold.effectiveWhen.valueBoolean extension
     */
    valueBoolean: string
    /**
     * The url for the threshold.effectiveWhen.valueBoolean extension
     */
    valueDecimal: string
    /**
     * The url for the threshold.effectiveWhen.valueBoolean extension
     */
    valueInteger: string
    /**
     * The url for the threshold.effectiveWhen.valueBoolean extension
     */
    valueString: string
    /**
     * The url for the threshold.effectiveWhen.valueBoolean extension
     */
    valueDate: string
    /**
     * The url for the threshold.effectiveWhen.valueBoolean extension
     */
    valueDateTime: string
    /**
     * The url for the threshold.effectiveWhen.valueBoolean extension
     */
    valueUri: string
    /**
     * The url for the threshold.effectiveWhen.valueBoolean extension
     */
    valueAttachment: string
    /**
     * The url for the threshold.effectiveWhen.valueBoolean extension
     */
    valueCodeableConcept: string
    /**
     * The url for the threshold.effectiveWhen.valueBoolean extension
     */
    valueQuantity: string
    /**
     * The url for the threshold.effectiveWhen.valueBoolean extension
     */
    valueReference: string
    /**
     * The url for the threshold.effectiveWhen.operator extension
     */
    operator: string
  } = {
    version:
      'https://issuetracker4s.atlassian.net/wiki/spaces/FHIRReg/pages/100499511/ThresholdSet+version+extension',
    status:
      'https://issuetracker4s.atlassian.net/wiki/spaces/FHIRReg/pages/100433991/ThresholdSet+status+extension',
    approvalDate:
      'https://issuetracker4s.atlassian.net/wiki/spaces/FHIRReg/pages/100433995/ThresholdSet+approvalDate+extension',
    approvingPractitioner:
      'https://issuetracker4s.atlassian.net/wiki/spaces/FHIRReg/pages/100565062/ThresholdSet+approvingPractitioner+extension',
    appliesTo:
      'https://issuetracker4s.atlassian.net/wiki/spaces/FHIRReg/pages/100728906/ThresholdSet+appliesTo+extension',
    threshold:
      'https://issuetracker4s.atlassian.net/wiki/spaces/FHIRReg/pages/100499515/ThresholdSet+threshold+extension',
    type:
      'https://issuetracker4s.atlassian.net/wiki/spaces/FHIRReg/pages/100728891/ThresholdSet+type+coding+system',
    effectiveWhen:
      'https://issuetracker4s.atlassian.net/wiki/spaces/FHIRReg/pages/100728921/ThresholdSet+effectiveWhen+extension',
    effectiveBehavior:
      'https://issuetracker4s.atlassian.net/wiki/spaces/FHIRReg/pages/100728931/ThresholdSet+effectiveBehavior+extension',
    component:
      'https://issuetracker4s.atlassian.net/wiki/spaces/FHIRReg/pages/100728925/ThresholdSet+component+extension',
    valueBoolean:
      'https://issuetracker4s.atlassian.net/wiki/spaces/FHIRReg/pages/100565090/ThresholdSet+valueBoolean+extension',
    valueDecimal:
      'https://issuetracker4s.atlassian.net/wiki/spaces/FHIRReg/pages/110395417/ThresholdSet+valueDecimal+extension',
    valueInteger:
      'https://issuetracker4s.atlassian.net/wiki/spaces/FHIRReg/pages/110428187/ThresholdSet+valueInteger+extension',
    valueString:
      'https://issuetracker4s.atlassian.net/wiki/spaces/FHIRReg/pages/110395423/ThresholdSet+valueString+extension',
    valueDate:
      'https://issuetracker4s.atlassian.net/wiki/spaces/FHIRReg/pages/110395427/ThresholdSet+valueDate+extension',
    valueDateTime:
      'https://issuetracker4s.atlassian.net/wiki/spaces/FHIRReg/pages/110395433/ThresholdSet+valueDateTime+extension',
    valueUri:
      'https://issuetracker4s.atlassian.net/wiki/spaces/FHIRReg/pages/110428237/ThresholdSet+valueUri+extension',
    valueAttachment:
      'https://issuetracker4s.atlassian.net/wiki/spaces/FHIRReg/pages/110460973/ThresholdSet+valueAttachment+extension',
    valueCodeableConcept:
      'https://issuetracker4s.atlassian.net/wiki/spaces/FHIRReg/pages/110460977/ThresholdSet+valueCodeableConcept+extension',
    valueQuantity:
      'https://issuetracker4s.atlassian.net/wiki/spaces/FHIRReg/pages/110460983/ThresholdSet+valueQuantity+extension',
    valueReference:
      'https://issuetracker4s.atlassian.net/wiki/spaces/FHIRReg/pages/110460998/ThresholdSet+valueReference+extension',
    operator:
      'https://issuetracker4s.atlassian.net/wiki/spaces/FHIRReg/pages/100499530/ThresholdSet+operator+extension',
  }
}
