import { expect } from 'chai'
import { AlreadyExistsError, MissingPropertyError } from 'exceptions'
import { MalformedError } from 'exceptions/malformed-error';

describe('AlreadyExistsError', () => {
  it('should be able to create minimal AlreadyExistsError', () => {
    expect(new AlreadyExistsError().message).to.eql('Already exists')
  })

  it('should allow for setting error-message', () => {
    expect(new AlreadyExistsError('other message').message).to.eql(
      'other message'
    )
  })

  it('should allow for adding conflicts in string form', () => {
    expect(new AlreadyExistsError('message', 'id', 'id2').conflicts).to.eql([
      'id',
      'id2',
    ])
  })

  it('should allow for adding conflicts through other errors', () => {
    const error1 = new AlreadyExistsError('message', 'id', 'id2')
    const error2 = new AlreadyExistsError('message', 'id3', 'id4')
    expect(new AlreadyExistsError('message', error1, error2).conflicts).to.eql([
      'id',
      'id2',
      'id3',
      'id4',
    ])
  })
})

describe('MissingPropertyError', () => {
  it('should be able to create minimal AlreadyExistsError', () => {
    expect(new MissingPropertyError().message).to.eql('Property is missing')
  })

  it('should allow for setting error-message', () => {
    expect(new MissingPropertyError('other message').message).to.eql(
      'other message'
    )
  })
})

describe('MalformedError', () => {
  it('should be able to create minimal MalformedError', () => {
    expect(new MalformedError().message).to.eql('Malformed')
  })

  it('should allow for setting error-message', () => {
    expect(new MalformedError('other message').message).to.eql(
      'other message'
    )
  })
})
