import { Resource } from 'fhir'

/**
 * Returns a deep copy of the object passed to it
 * @param { T } object The object to create a clone of
 * @returns { T } The clone of the object
 */
export const deepcopy: <T extends Resource>(object: T) => T = object => {
  return JSON.parse(JSON.stringify(object))
}

/**
 * Returns regular expression for ISO date string
 */
export const isodateRegex = () => {
  return new RegExp(
    /(\d{4}-[01]\d-[0-3]\dT[0-2]\d:[0-5]\d:[0-5]\d\.\d+([+-][0-2]\d:[0-5]\d|Z))|(\d{4}-[01]\d-[0-3]\dT[0-2]\d:[0-5]\d:[0-5]\d([+-][0-2]\d:[0-5]\d|Z))|(\d{4}-[01]\d-[0-3]\dT[0-2]\d:[0-5]\d([+-][0-2]\d:[0-5]\d|Z))/
  )
}
